import { useState, useEffect } from 'react'
import { Link } from 'react-router-dom'
import axios from 'axios'
import { format } from 'date-fns'
import './Blog.css'

function Blog() {
  const [posts, setPosts] = useState([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState(null)
  const [selectedTag, setSelectedTag] = useState(null)

  useEffect(() => {
    const fetchPosts = async () => {
      try {
        const response = await axios.get('http://localhost:5000/api/posts')
        setPosts(response.data)
        setLoading(false)
      } catch (err) {
        console.error('Error fetching posts:', err)
        setError('Failed to load blog posts. Please try again later.')
        setLoading(false)
      }
    }

    fetchPosts()
  }, [])

  // Extract all unique tags from posts
  const allTags = posts.reduce((tags, post) => {
    if (post.tags) {
      post.tags.forEach(tag => {
        if (!tags.includes(tag)) {
          tags.push(tag)
        }
      })
    }
    return tags
  }, [])

  // Filter posts by selected tag
  const filteredPosts = selectedTag
    ? posts.filter(post => post.tags && post.tags.includes(selectedTag))
    : posts

  if (loading) return <div className="loading">Loading posts...</div>
  if (error) return <div className="error">{error}</div>

  return (
    <div className="blog-page">
      <div className="container">
        <h1>Blog</h1>
        
        {allTags.length > 0 && (
          <div className="tags-filter">
            <span>Filter by tag: </span>
            <button 
              className={selectedTag === null ? 'active' : ''} 
              onClick={() => setSelectedTag(null)}
            >
              All
            </button>
            {allTags.map(tag => (
              <button
                key={tag}
                className={selectedTag === tag ? 'active' : ''}
                onClick={() => setSelectedTag(tag)}
              >
                {tag}
              </button>
            ))}
          </div>
        )}
        
        <div className="posts-list">
          {filteredPosts.length === 0 ? (
            <p>No posts found.</p>
          ) : (
            filteredPosts.map(post => (
              <article key={post.slug} className="post-card">
                <h2>
                  <Link to={`/blog/${post.slug}`}>{post.title}</Link>
                </h2>
                <div className="post-meta">
                  <time>{format(new Date(post.date), 'MMMM d, yyyy')}</time>
                  {post.tags && (
                    <div className="post-tags">
                      {post.tags.map(tag => (
                        <span key={tag} className="tag" onClick={() => setSelectedTag(tag)}>
                          {tag}
                        </span>
                      ))}
                    </div>
                  )}
                </div>
                <p className="post-excerpt">{post.excerpt}</p>
                <Link to={`/blog/${post.slug}`} className="read-more">
                  Read more →
                </Link>
              </article>
            ))
          )}
        </div>
      </div>
    </div>
  )
}

export default Blog